<?php

declare(strict_types=1);

namespace Psalm\Node\Scalar\MagicConst;

use PhpParser\Node\Scalar\MagicConst\Dir;
use Psalm\Node\VirtualNode;

final class VirtualDir extends Dir implements VirtualNode
{

}
