OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "تختهٔ جدیدی به نام {board} ایجاد کردید",
    "{user} has created a new board {board}" : "{user} یک تخته جدیدی به نام {board} ایجاد کرد",
    "You have deleted the board {board}" : "تختهٔ {board} را حذف کردید",
    "{user} has deleted the board {board}" : "{user} تختهٔ {board} را حذف کرد",
    "You have restored the board {board}" : "تختهٔ {board} را بازیابی کردید",
    "{user} has restored the board {board}" : "{user} تختهٔ {board} را بازیابی کرد",
    "You have shared the board {board} with {acl}" : "تختهٔ {board} را با {acl} هم‌رسانی کردید",
    "{user} has shared the board {board} with {acl}" : "{user} تختهٔ {board} را با {acl} هم‌رسانی کرد",
    "You have removed {acl} from the board {board}" : "شما {acl} را از تختهٔ {board} حذف کردید",
    "{user} has removed {acl} from the board {board}" : "{user} اقدام به حذف {acl} از تختهٔ {board} کرد",
    "You have renamed the board {before} to {board}" : "نام تخته را از {before} به {board} تغییر دادید",
    "{user} has renamed the board {before} to {board}" : "{user} نام تخته را از {before} به {board} تغییر داد",
    "You have archived the board {board}" : "تختهٔ {board} را بایگانی کردید",
    "{user} has archived the board {before}" : "{user} تختهٔ {board} را بایگانی کرد",
    "You have unarchived the board {board}" : "تختهٔ {board} را از بایگانی خارج کردید",
    "{user} has unarchived the board {before}" : "{user} تختهٔ {board} را از بایگانی خارج کرد",
    "You have created a new list {stack} on board {board}" : "شما فهرست جدید {stack} را در تخته {board} ایجاد کرده‌اید",
    "{user} has created a new list {stack} on board {board}" : "{user} فهرست جدید {stack} را در تخته {board} ایجاد کرده است",
    "You have renamed list {before} to {stack} on board {board}" : "شما فهرست {before} را به {stack} در تخته {board} تغییر نام داده‌اید",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} فهرست {before} را به {stack} در تخته {board} تغییر نام داده است",
    "You have deleted list {stack} on board {board}" : "شما فهرست {stack} را در تخته {board} حذف کرده اید",
    "{user} has deleted list {stack} on board {board}" : "{user} فهرست {stack} را در تخته {board} حذف کرده است",
    "You have created card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} ایجاد کرده اید",
    "{user} has created card {card} in list {stack} on board {board}" : "ٰ{user} برگه {card} را در فهرست {stack} در تخته {board} ایجاد کرده است",
    "You have deleted card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} حذف کرده اید",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} برگه {card} را در فهرست {stack} در تخته {board} حذف کرده است",
    "You have renamed the card {before} to {card}" : "شما نام برگه را {پیش از} به {card} تغییر داده اید",
    "{user} has renamed the card {before} to {card}" : "{user} نام برگه را {پیش از} به {card} تغییر داده است",
    "You have added a description to card {card} in list {stack} on board {board}" : "شما یک توضیح به برگه {card} در فهرست {stack} در تخته {board} اضافه کرده اید",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} توضیحاتی را به برگه {card} در فهرست {stack} on board {board} اضافه کرده است.",
    "You have updated the description of card {card} in list {stack} on board {board}" : "شما شرح برگه {card} را در فهرست {stack} در تخته {board} به روز کرده اید.",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} توضیحات برگه {card} را در فهرست {stack} on board {board} به روز کرده است.",
    "You have archived card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} بایگانی کرده اید",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} برگه {card} را در فهرست {stack} در تخته {board} بایگانی کرده است",
    "You have unarchived card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} از بایگانی خارج کرده‌اید.",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} برگه {card} را در فهرست {stack} در تخته {board} از بایگانی خارج کرده است",
    "You have removed the due date of card {card}" : "شما تاریخ سررسید برگه {card} را حذف کرده اید",
    "{user} has removed the due date of card {card}" : "{user} تاریخ سررسید برگه {card} را حذف کرده است",
    "You have set the due date of card {card} to {after}" : "شما تاریخ سررسید برگه {card} را روی {after} تنظیم کرده اید",
    "{user} has set the due date of card {card} to {after}" : "{user} تاریخ سررسید برگه {card} را روی {after} قرار داده است",
    "You have updated the due date of card {card} to {after}" : "شما تاریخ سررسید برگه {card} را به {after} به روز کرده اید",
    "{user} has updated the due date of card {card} to {after}" : "{user} تاریخ سررسید برگه {card} را به {after} به روز کرده است",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "شما برچسب {label} را به برگه {card} در فهرست {stack} در تخته {board} اضافه کرده‌اید.",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} برچسب {label} را بهبرگه {card} در فهرست {stack} در تخته {board} اضافه کرده است.",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "شما برچسب {label} را از برگه {card} در فهرست {stack} در تخته {board} حذف کردید.",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} برچسب {label} را از برگه {card} در فهرست {stack} در تخته {board} حذف کرده است.",
    "You have assigned {assigneduser} to card {card} on board {board}" : "شما {کاربر اختصاص یافته} را به برگه {card} در تخته {board} اختصاص داده‌اید.",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} {assigneduser} را به برگه {card} در تخته {board} اختصاص داده است",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "شما {تخصیص کاربر} را از برگه {card} در تخته {board} لغو کرده‌اید.",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} تخصیص {assigneduser} را از برگه {card} در تخته لغو کرده است",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "شما برگه {card} را از فهرست {stackBefore} به {stack} منتقل کرده اید",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} برگه {card} را از فهرست {stackBefore} به {stack} منتقل کرده است",
    "You have added the attachment {attachment} to card {card}" : "شما پیوست {attachment} را به برگه {card} اضافه کرده‌اید.",
    "{user} has added the attachment {attachment} to card {card}" : "{user} پیوست {attachment} را به برگه {card} اضافه کرده است",
    "You have updated the attachment {attachment} on card {card}" : "شما پیوست {attachment} را در برگه {card} به روز کرده اید",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} پیوست {attachment} را در برگه {card} به روز کرده است",
    "You have deleted the attachment {attachment} from card {card}" : "شما پیوست {attachment} را از برگه {card} حذف کرده اید",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} پیوست {attachment} را ازبرگه {card} حذف کرده است",
    "You have restored the attachment {attachment} to card {card}" : "شما پیوست {attachment} را به برگه {card} بازیابی کرده اید",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} پیوست {attachment} را به برگه {card} بازیابی کرده است",
    "You have commented on card {card}" : "شما در مورد برگه {card} نظر داده اید",
    "{user} has commented on card {card}" : "{user} روی برگه {card} نظر داده است",
    "Deck" : "برگه‌دان",
    "Changes in the <strong>Deck app</strong>" : "تغییرات در برگه‌دان",
    "A <strong>comment</strong> was created on a card" : "یک نظر روی یک برگه ایجاد شد",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
    "The file was only partially uploaded" : "پرونده فقط به صورت جزئی و ناقص بارگذاری شد",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "Missing a temporary folder" : "یک پوشه موقت گم شده",
    "Could not write file to disk" : "عدم موفقیت در نوشتن پرونده روی حافظه",
    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
    "No file uploaded or file size exceeds maximum of %s" : "پرونده‌ای بارگذاری نشد و یا حجم پرونده بیش از بیشینه مجاز %s بود",
    "Upcoming cards" : "برگه‌های آینده",
    "Load more" : "Load more",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "The card \"%s\" on \"%s\" has been assigned to you by %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} برگه {deck-card} در {deck-board} را به شما اختصاص داده است.",
    "The card {deck-card} on {deck-board} has reached its due date." : "برگه {deck-card} در {deck-board} به تاریخ سررسید خود رسیده است.",
    "%s has mentioned you in a comment on \"%s\"." : "%s has mentioned you in a comment on \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} از شما در نظری در {deck-card} نام برده است.",
    "The board \"%s\" has been shared with you by %s." : "The board \"%s\" has been shared with you by %s.",
    "{user} has shared {deck-board} with you." : "{user} {deck-board} را با شما به اشتراک گذاشته است.",
    "Deck board" : "تخته deck",
    "Owned by %1$s" : "Owned by %1$s",
    "Deck boards, cards and comments" : "Deck boards, cards and comments",
    "From %1$s, in %2$s/%3$s, owned by %4$s" : "From %1$s, in %2$s/%3$s, owned by %4$s",
    "Create a new deck card" : "Create a new deck card",
    "Card comments" : "دیدگاه‌های برگه",
    "%s on %s" : "%s on %s",
    "Deck boards and cards" : "Deck boards and cards",
    "No data was provided to create an attachment." : "هیچ داده ای برای ایجاد پیوست ارائه نشد.",
    "Finished" : "تمام شده",
    "To review" : "برای بازبینی",
    "Action needed" : "نیازمند اقدام",
    "Later" : "بعدا",
    "copy" : "کپی",
    "To Do" : "To Do",
    "Done" : "انجام شد",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s.",
    "Attachments" : "پیوست‌ها",
    "File" : "پرونده",
    "Card not found" : "برگه یافت نشد",
    "Path is already shared with this card" : "مسیر قبلاً با این برگه به اشتراک گذاشته شده است",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است، قالب تاریخ باید YYYY-MM-DD باشد",
    "Personal planning and team project organization" : "برنامه‌ریزی شخصی و سازمان‌دهی کار گروهی",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "برگه‌دان یک ابزار سازمان‌دهی سبک کانبان است که هدف آن برنامه‌ریزی شخصی و سازمان‌دهی پروژه برای گروه‌های مرتبط با Nextcloud است.\n\n\n- 📥 وظایف خود را به برگه‌ها اضافه کنید و آن‌ها را مرتب کنید\n- 📄 یادداشت‌های اضافی را در Markdown یادداشت کنید\n- 🔖 برچسب‌هایی را برای سازمان‌دهی بهتر اختصاص دهید\n- 👥 با گروه، دوستان یا خانوادهٔ خود به اشتراک بگذارید\n- 📎 فایل‌ها را ضمیمه کنید و آنها را در توضیحات Markdown خود قرار دهید\n- 💬 با استفاده از نظرات با تیم خود بحث کنید\n- ⚡ تغییرات در جریان فعالیت را پیگیری کنید\n- 🚀 پروژه خود را سازمان‌دهی کنید",
    "Add board" : "افزودن تخته",
    "Card details" : "جزئیات برگه",
    "Select the board to link to a project" : "تخته‌ای را برای ایجاد پیوند با یک پروژه انتخاب کنید",
    "Search by board title" : "جستجو بر اساس عنوان تخته",
    "Select board" : "انتخاب تخته",
    "Select a board" : "انتخاب یک تخته",
    "No lists available" : "هیچ فهرستی در دسترس نیست",
    "Select a list" : "یک فهرست برگزینید",
    "Move card" : "انتقال برگه",
    "Select the card to link to a project" : "برگه‌ای را برای ایجاد پیوند با یک پروژه انتخاب کنید",
    "Link to card" : "پیوند به برگه",
    "Select a card" : "انتخاب یک برگه",
    "Cancel" : "لغو",
    "This board is read only" : "تخته، فقط خواندنی است",
    "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
    "File already exists" : "پرونده از قبل موجود است",
    "A file with the name {filename} already exists." : "پرونده‌ای با نام {filename} از قبل موجود است.",
    "Do you want to overwrite it?" : "می‌خواهید روی آن بازنویسی شود؟",
    "Overwrite file" : "بازنویسی پرونده",
    "Keep existing file" : "پرونده موجود حفظ شود",
    "Add card" : "افزودن برگه",
    "Archived cards" : "کارت‌های بایگانی‌شده",
    "Add list" : "افزودن فهرست",
    "List name" : "نام فهرست",
    "Active filters" : "Active filters",
    "Apply filter" : "اعمال پالایه",
    "Filter by tag" : "پالایش برحسب برچسب",
    "Filter by assigned user" : "فیلتر بر اساس کاربر اختصاص داده شده",
    "Unassigned" : "اختصاص داده نشده است",
    "Open" : "باز کردن",
    "Completed" : "نکمیل شده",
    "Filter by due date" : "فیلتر بر اساس تاریخ مقرر",
    "Overdue" : "تاریخ گذشته",
    "Next 24 hours" : "۲۴ ساعت آینده",
    "Next 7 days" : "۷ روز آینده",
    "Next 30 days" : "۳۰ روز آینده",
    "No due date" : "بدون تاریخ سررسید",
    "Clear filter" : "پاک کردن پالایه",
    "Hide archived cards" : "برگه‌های بایگانی شده را مخفی کنید",
    "Show archived cards" : "نمایش کارت‌های بایگانی شده",
    "Toggle compact mode" : "تغییر حالت فشرده",
    "Open details" : "باز کردن جزئیات",
    "Details" : "جزئیات",
    "Deck settings" : "Deck settings",
    "General" : "عمومی",
    "Use bigger card view" : "از نمای برگهٔ بزرگتر استفاده کنید",
    "Appearance" : "ظاهر",
    "Show card ID badge" : "Show card ID badge",
    "Show boards in calendar/tasks" : "نمایش تابلوها در تقویم/ وظایف",
    "Search" : "جستجو",
    "Show those shortcuts" : "نمایش میانبرها",
    "Currently present people" : "Currently present people",
    "Loading board" : "بارکردن تخته",
    "Board not found" : "تخته یافت نشد",
    "Create a new list to add cards to this board" : "یک فهرست جدید برای افزود برگه به این تابلو ایجاد کنید",
    "Sharing" : "هم‌رسانی",
    "Tags" : "برچسب‌ها",
    "Deleted items" : "موارد حذف شده",
    "Activity" : "فعالیت",
    "Deleted lists" : "فهرست‌های پاک شده",
    "Undo" : "برگرداندن",
    "Deleted cards" : "کارت‌های پاک شده",
    "Hours" : "ساعت ها",
    "Days" : "روزها",
    "Weeks" : "هفته‌ها",
    "Months" : "ماه‌ها",
    "No cards yet" : "هنوز کارت وجود ندارد",
    "Failed to create share with {displayName}" : "اشتراک‌گذاری با {displayName} ایجاد نشد",
    "Are you sure you want to transfer the board {title} to {user}?" : "Are you sure you want to transfer the board {title} to {user}?",
    "Transfer the board." : "Transfer the board.",
    "Transfer" : "انتقال",
    "The board has been transferred to {user}" : "The board has been transferred to {user}",
    "Failed to transfer the board to {user}" : "Failed to transfer the board to {user}",
    "Board owner" : "مالک تخته",
    "(Group)" : "(گروه)",
    "(remote)" : "(از راه دور)",
    "Can edit" : "می‌تواند ویرایش کند",
    "Can share" : "می‌تواند هم‌رسانی کند",
    "Can manage" : "می‌تواند مدیریت کند",
    "Owner" : "مالک",
    "Delete" : "حذف",
    "List deleted" : "فهرست پاک شد",
    "Edit list title" : "Edit list title",
    "Archive all cards" : "همهٔ برگه‌ها را بایگانی کنید!",
    "Unarchive all cards" : "Unarchive all cards",
    "Delete list" : "حذف فهرست",
    "Archive all cards in this list" : "تمام برگه‌های موجود در این فهرست را بایگانی کنید",
    "Unarchive all cards in this list" : "Unarchive all cards in this list",
    "Add a new card" : "افزودن یک کارت جدید",
    "Card name" : "نام برگه",
    "title and color value must be provided" : "نام و رنگ باید مشخص شود",
    "Edit" : "ویرایش",
    "Add a new tag" : "افزودن یک برچسب جدید",
    "Board name" : "نامِ تخته",
    "Members" : "اعضا",
    "Assign a user to this card…" : "اختصاص یک کاربر به این برگه…",
    "File to share" : "فایل برای اشتراک‌گذاری",
    "Invalid path selected" : "مسیر نامعتبر انتخاب شده است",
    "Upload new files" : "فایل‌های جدید را آپلود کنید",
    "Share from Files" : "اشتراک‌گذاری از فایل‌ها",
    "Pending share" : "سهم معلق",
    "Add this attachment" : "افزودن این پیوست",
    "Show in Files" : "نمایش در فایل‌ها",
    "Download" : "بارگیری",
    "Remove attachment" : "حذف پیوست",
    "Delete Attachment" : "حذف پیوست",
    "Restore Attachment" : "بازیابی پیوست",
    "The title cannot be empty." : "عنوان نمی‌تواند خالی باشد.",
    "Open in sidebar view" : "در نمای نوار کناری باز کنید",
    "Open in bigger view" : "در نمای بزرگتر باز کنید",
    "Comments" : "نظرات",
    "Failed to load comments" : "نظرات بارگیری نشد",
    "No comments yet. Begin the discussion!" : "هنوز نظری وجود ندارد. بحثی را آغاز کنید!",
    "The comment cannot be empty." : "نظر نمی‌تواند خالی باشد.",
    "The comment cannot be longer than 1000 characters." : "نظر نمی‌تواند طولانی‌تر از ۱۰۰۰ حرف باشد.",
    "Submit" : "ارسال",
    "Created:" : "ایجاد شده توسط:",
    "In reply to" : "در پاسخ به",
    "Cancel reply" : "لغو پاسخ",
    "Reply" : "پاسخ",
    "Update" : "به‌روزرسانی",
    "Mark as done" : "علامت گذاری به عنوان انجام شده",
    "Write a description …" : "توضیح بنویس…",
    "Description" : "توضیحات",
    "(Unsaved)" : "(ذخیره نشده)",
    "(Saving…)" : "(در حال ذخیره...)",
    "Formatting help" : "راهنمای قالب‌بندی",
    "Edit description" : "ویرایش توضیحات",
    "View description" : "نمایش توضیحات",
    "Add Attachment" : "افزودن پیوست",
    "Choose attachment" : "انتخاب پیوست",
    "Select Date" : "تاریخ را انتخاب کنید",
    "Later today – {timeLocale}" : "Later today – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Tomorrow – {timeLocale}",
    "This weekend – {timeLocale}" : "This weekend – {timeLocale}",
    "Next week – {timeLocale}" : "Next week – {timeLocale}",
    "Assign a due date to this card…" : "Assign a due date to this card…",
    "Set a due date" : "تاریخ سررسید را تعیین کنید",
    "Remove due date" : "تاریخ سررسید را حذف کنید",
    "Unarchive card" : "برگه را از بایگانی خارج کنید",
    "Archive card" : "بایگانی برگه",
    "Assign a tag to this card…" : "یک برچسب به این برگه اختصاص دهید…",
    "(group)" : "(گروه)",
    "{count} comments, {unread} unread" : "{count} نظر، { خوانده نشده} خوانده نشده",
    "Todo items" : "Todo items",
    "Edit card title" : "Edit card title",
    "Open link" : "لینک را باز کنید",
    "Card deleted" : "برگه پاک شد",
    "Edit title" : "ویرایش عنوان",
    "Assign to me" : "به من اختصاص دهید",
    "Unassign myself" : "واگذاری به خودم را لغو می‌کنم",
    "Delete card" : "حذف برگه",
    "seconds ago" : "ثانیه‌هایی پیش",
    "All boards" : "همه تخته‌ها",
    "Archived boards" : "تخته‌های بایگانی شده",
    "Shared with you" : "با شما به اشتراک گذاشته شده است",
    "Cancel edit" : "Cancel edit",
    "Board {0} deleted" : "Board {0} deleted",
    "All cards" : "All cards",
    "Only assigned cards" : "Only assigned cards",
    "No reminder" : "No reminder",
    "An error occurred" : "خطایی روی داد",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards.",
    "Delete the board?" : "Delete the board?",
    "Leave" : "خروج",
    "Board details" : "Board details",
    "Edit board" : "ویرایش تخته",
    "Clone board" : "تخته شبیه‌سازی",
    "Unarchive board" : "Unarchive board",
    "Archive board" : "تخته",
    "Export board" : "Export board",
    "Turn on due date reminders" : "Turn on due date reminders",
    "Turn off due date reminders" : "Turn off due date reminders",
    "Due date reminders" : "Due date reminders",
    "Assigned cards" : "Assigned cards",
    "No notifications" : "بدون اعلان",
    "Delete board" : "حذف تخته",
    "Clone cards" : "شبیه سازی کارت",
    "Advanced options" : "گزینه‌های پیش‌رفته",
    "Clone" : "شبیه سازی",
    "Export as CSV" : "Export as CSV",
    "Export" : "دریافت خروجی",
    "Loading filtered view" : "Loading filtered view",
    "Search for {searchQuery} in all boards" : "Search for {searchQuery} in all boards",
    "No results found" : "هیچ نتیجه ای یافت نشد",
    "Deck board {name}\n* Last modified on {lastMod}" : "Deck board {name}\n* Last modified on {lastMod}",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments",
    "{nbCards} cards" : "{nbCards} cards",
    "Due on {date}" : "Due on {date}",
    "{stack} in {board}" : "{stack} in {board}",
    "Click to expand description" : "Click to expand description",
    "Click to expand comment" : "Click to expand comment",
    "Create card" : "ایجاد برگه",
    "Create a new card" : "یک برگهٔ جدید بسازید",
    "Card title" : "عنوان برگه",
    "Creating the new card …" : "ساختن برگهٔ جدید ...",
    "Card \"{card}\" was added to \"{board}\"" : "برگه \"{card}\" به \"{board}\" اضافه شد",
    "Open card" : "بازکردن برگه",
    "Close" : "بستن",
    "No upcoming cards" : "No upcoming cards",
    "upcoming cards" : "upcoming cards",
    "New card" : "New card",
    "Link to a board" : "Link to a board",
    "Link to a card" : "Link to a card",
    "Create a card" : "Create a card",
    "Message from {author} in {conversationName}" : "پیام از {author} در {conversationName}",
    "Something went wrong" : "Something went wrong",
    "Failed to upload {name}" : "Failed to upload {name}",
    "Maximum file size of {size} exceeded" : "Maximum file size of {size} exceeded",
    "Due date" : "تاریخ سررسید",
    "Created" : "ایجاد شده",
    "Modified" : "تغییر یافته",
    "Error creating the share" : "خطایی در ایجاد اشتراک",
    "Share with a Deck card" : "Share with a Deck card",
    "Share {file} with a Deck card" : "Share {file} with a Deck card",
    "Share" : "هم‌رسانی",
    "The card \"%s\" on \"%s\" has reached its due date." : "The card \"%s\" on \"%s\" has reached its due date.",
    "No participants found" : "هیچ شرکتی پیدا نشد",
    "Save" : "ذخیره",
    "Today" : "Today",
    "Tomorrow" : "فردا",
    "No due" : "No due"
},
"nplurals=2; plural=(n > 1);");
