"use strict";(self.webpackChunkdeck=self.webpackChunkdeck||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_index-BMbtc3xh_mjs"],{83731(e,s,d){d.d(s,{FilePickerVue:()=>_});const _=(0,d(85471).$V)(()=>d.e("vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-JKNLPCbR_mjs").then(d.bind(d,56876)))}}]);
//# sourceMappingURL=deck-node_modules_nextcloud_dialogs_dist_chunks_index-BMbtc3xh_mjs.js.map?v=134b4cd01d4e00fa3a57