<?php return array(
    'root' => array(
        'name' => 'nextcloud/deck',
        'pretty_version' => 'v1.17.2',
        'version' => '1.17.2.0',
        'reference' => 'bcc8032dc9944c78aa45729fe263c33635816fbf',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.8.3',
            'version' => '1.8.3.0',
            'reference' => 'e7ef9e012667327516c24e5fad9903a3bc91389d',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'justinrainbow/json-schema' => array(
            'pretty_version' => '6.6.4',
            'version' => '6.6.4.0',
            'reference' => '2eeb75d21cf73211335888e7f5e6fd7440723ec7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../justinrainbow/json-schema',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'marc-mabe/php-enum' => array(
            'pretty_version' => 'v4.7.1',
            'version' => '4.7.1.0',
            'reference' => '7159809e5cfa041dca28e61f7f7ae58063aae8ed',
            'type' => 'library',
            'install_path' => __DIR__ . '/../marc-mabe/php-enum',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nextcloud/deck' => array(
            'pretty_version' => 'v1.17.2',
            'version' => '1.17.2.0',
            'reference' => 'bcc8032dc9944c78aa45729fe263c33635816fbf',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
